@@ -131,7 +131,7 @@ partial.corr.matrix <- function(S){
 
 ## Output function ##
 outfun <- function(Sigma, S, n){
-    ell <- function(Sigma, S, n){
+    .ell <- function(Sigma, S, n){
         
         shdet <- function(Sigma){
             prod(eigen(Sigma)[[1]])
@@ -145,7 +145,7 @@ outfun <- function(Sigma, S, n){
                 eigenvalues=eigen(Sigma)[[1]],
                 correlation=cov2cor(Sigma),###corr.matrix(Sigma),
                 partial.correlations=partial.corr.matrix(Sigma),
-                loglik=ell(Sigma,S,n)))
+                loglik=.ell(Sigma,S,n)))
 }
 
 
